from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self) -> int:
		"""SCPI: [SENSe]:EVALuation:PACKet:COUNt \n
		Snippet: value: int = driver.applications.k149Uwb.sense.evaluation.packet.count.get() \n
		Returns the number of packets analyzed. \n
			:return: result: No help available"""
		response = self._core.io.query_str(f'SENSe:EVALuation:PACKet:COUNt?')
		return Conversions.str_to_int(response)
