from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NoRbCls:
	"""NoRb commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("noRb", core, parent)

	def set(self, resource_blocks: float, carrierComponent=repcap.CarrierComponent.Default) -> None:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:PUCCh:NORB \n
		Snippet: driver.applications.k10Xlte.configure.lte.uplink.cc.pucch.noRb.set(resource_blocks = 1.0, carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the number of resource blocks for the PUCCH. \n
			:param resource_blocks: numeric value Selects the number of RBs. AUTO Detects the number of RBs automatically.
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
		"""
		param = Conversions.decimal_value_to_str(resource_blocks)
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		self._core.io.write(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:PUCCh:NORB {param}')

	def get(self, carrierComponent=repcap.CarrierComponent.Default) -> float:
		"""SCPI: CONFigure[:LTE]:UL[:CC<cc>]:PUCCh:NORB \n
		Snippet: value: float = driver.applications.k10Xlte.configure.lte.uplink.cc.pucch.noRb.get(carrierComponent = repcap.CarrierComponent.Default) \n
		This command selects the number of resource blocks for the PUCCH. \n
			:param carrierComponent: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cc')
			:return: resource_blocks: numeric value Selects the number of RBs. AUTO Detects the number of RBs automatically."""
		carrierComponent_cmd_val = self._cmd_group.get_repcap_cmd_value(carrierComponent, repcap.CarrierComponent)
		response = self._core.io.query_str(f'CONFigure:LTE:UL:CC{carrierComponent_cmd_val}:PUCCh:NORB?')
		return Conversions.str_to_float(response)
